@@ -28,7 +28,7 @@ Implementation Notes
   https://github.com/adafruit/Adafruit_CircuitPython_seesaw/releases
 """
 
-__version__ = "1.2.3"
+__version__ = "1.3.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_neotrellis.git"
 
 
@@ -100,6 +100,12 @@ class MultiTrellis:
                             x = int(evt.number % 4) + _m * 4
                             _t.callbacks[evt.number](x, y, evt.edge)
 
+    def show(self):
+        """Show the colors on the NeoPixels"""
+        for _n in range(self._rows):
+            for _m in range(self._cols):
+                self._trelli[_n][_m].show()
+
     @property
     def brightness(self):
         """The NeoPixel brightness level of all clustered NeoTrellis boards."""
